@@ -222,7 +222,7 @@ class Bib(object):
       >>> import bibmanager.bib_manager as bm
       >>> bib = bm.Bib('''@ARTICLE{DoeEtal2020,
                       author = {{Doe}, J. and {Perez}, J. and {Dupont}, J.},
-                       title = "What Have the Astromomers ever Done for Us?",
+                       title = "What Have the Astronomers ever Done for Us?",
                      journal = {\apj},
                         year = 2020,}''')
       >>> # Check for first author:
@@ -461,7 +461,23 @@ def remove_duplicates(bibs, field):
         if nbibs == 1:
             continue
 
-        # Querry the user:
+        # If field is isbn, check doi to differentiate chapters from same book:
+        if field == 'isbn':
+            dois = [
+                bibs[idx].doi if bibs[idx].doi is not None else ""
+                for idx in indices]
+            u_doi, doi_inv, doi_counts = np.unique(
+                dois, return_inverse=True, return_counts=True)
+            doi_multis = np.where((doi_counts > 1) & (ubib != ""))[0]
+            single_dois = u_doi[doi_counts==1]
+            indices = [
+                idx for idx,doi in zip(indices,dois)
+                if doi not in single_dois]
+            nbibs = len(indices)
+            if nbibs <= 1:
+                continue
+
+        # Query the user:
         labels = [idx + " ENTRY:\n" for idx in u.ordinal(np.arange(nbibs)+1)]
         display_bibs(labels, [bibs[i] for i in indices])
         s = u.req_input(
@@ -803,7 +819,7 @@ def merge(bibfile=None, new=None, take="old", base=None):
         'ask': Ask user to decide (interactively).
     base: List of Bib() objects
         If None, merge new entries into the bibmanager database.
-        If not None, merge new intries into base.
+        If not None, merge new entries into base.
 
     Returns
     -------
